Skip to contents

`mlr3filters::Filter` wrapper around [codaFS_plr_variance()].

Dictionary

This Filter can be instantiated via the dictionary `mlr_filters` or with the associated sugar function `flt()`: “` flt("coda_plr_variance") mlr_filters$get("coda_plr_variance") “`

Super class

mlr3filters::Filter -> FilterCoDA_PLRVariance

Methods

Inherited methods


Method new()

Creates a new instance of this Filter.


Method clone()

The objects of this class are cloneable with this method.

Usage

FilterCoDA_PLRVariance$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.