Register a non-canonical score adapter for a roster method
Source:R/singlesample-method-roster.R
singlesample_register_score_adapter.RdNew roster methods follow the canonical convention `score_*(model, X, meta = NULL)` and need no adapter. Legacy ("present") methods whose score function uses a different argument order register a shim mapping them onto the canonical `function(model, X, meta)` signature.