Eligible methods for the single-sample selector
Source:R/singlesample-selector.R
singlesample_selector_candidates.RdReturns the frozen tier-R1 method bank that can be considered by the experimental single-sample selector. The bank contains only within-cohort baselines and discriminators accepted by [deploy_singlesample()]; transfer estimands, conditional routes, negative controls, and reticulate routes are excluded.
Usage
singlesample_selector_candidates(roster = singlesample_method_roster())